Python package(JSPP) created by Jhin Scripter.  
[WIP] / BETA  
  
| Jhin Scripter Python Package (JSPP)  
  
Discord: Jhin Scripter#0922  
Youtube: https://www.youtube.com/channel/UCkyQbVJRI_38yB77eiSHBhw  
Twitter: @JhinScripter  
  
You will be able to report any errors or help improve the package on my discord (Just DM).